AnyLoadingIndicatorStyle class
IndicatorStyle used for AnyLoadingIndicator.
Constructors
- AnyLoadingIndicatorStyle({AnyLoadingIndicatorType indicatorType = AnyLoadingIndicatorType.circle, Color? color, double size = defaultIndicatorSize, BoxShape? shape, int? itemCount, double? strokeWidth, double? lineWidth, double? borderWidth, Duration? delay, Color? trackColor, Color? waveColor})
-
const
- AnyLoadingIndicatorStyle.dark({BoxShape? shape, int? itemCount, double? strokeWidth, double? lineWidth, double? borderWidth, Duration? delay, AnyLoadingIndicatorType indicatorType = AnyLoadingIndicatorType.circle, double size = defaultIndicatorSize})
-
factory
- AnyLoadingIndicatorStyle.light({BoxShape? shape, int? itemCount, double? strokeWidth, double? lineWidth, double? borderWidth, Duration? delay, AnyLoadingIndicatorType indicatorType = AnyLoadingIndicatorType.circle, double size = defaultIndicatorSize})
-
factory
Properties
- borderWidth → double?
-
only used for ripple
final
- color → Color?
-
color
final
- delay → Duration?
-
only used for threeInOut
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- indicatorType → AnyLoadingIndicatorType
-
indicatorType
final
- itemCount → int?
-
only used for spinKitWave or spinningLines or pianoWave
final
- lineWidth → double?
-
only used for ring or spinningLines or dualRing
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shape → BoxShape?
-
only used for wanderingCubes or fadingFour or fadingGrid or spinningCircle
final
- size → double
-
size
final
- strokeWidth → double?
-
only used for pouringHourGlass or pouringHourGlassRefined
final
- trackColor → Color?
-
only used for WaveSpinner
final
- waveColor → Color?
-
only used for WaveSpinner
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultErrorIcon → const Icon
- default success icon for AnyLoading.showError
- defaultIndicatorSize → const double
- default size of indicator
- defaultSuccessIcon → const Icon
- default success icon for AnyLoading.showSuccess